@@ -2308,6 +2308,9 @@ EXPORTED int annotatemore_msg_lookupmask(const char *mboxname, uint32_t uid, con
     if (!mboxname_userownsmailbox(userid, mboxname))
 	r = annotatemore_msg_lookup(mboxname, uid, entry, userid, value);
     /* and if there isn't one, we fall through to the shared value */
+    if (value->len == 0)
+	r = annotatemore_msg_lookup(mboxname, uid, entry, "", value);
+    /* and because of Bron's use of NULL rather than "" at FastMail... */
     if (value->len == 0)
 	r = annotatemore_msg_lookup(mboxname, uid, entry, NULL, value);
     return r;
@@ -2540,7 +2543,7 @@ EXPORTED int annotate_state_writemask(annotate_state_t *state,
 {
     /* if the user is the owner, then write to the shared namespace */
     if (mboxname_userownsmailbox(userid, state->mailbox->name))
-	return annotate_state_write(state, entry, NULL, value);
+	return annotate_state_write(state, entry, "", value);
     else
 	return annotate_state_write(state, entry, userid, value);
 }
@@ -2578,6 +2581,7 @@ static int annotate_canon_value(struct buf *value, int type)
     case ATTRIB_TYPE_UINT:
 	/* make sure its a valid ulong ( >= 0 ) */
 	errno = 0;
+	buf_cstring(value);
 	uwhatever = strtoul(value->s, &p, 10);
 	if ((p == value->s)		/* no value */
 	    || (*p != '\0')		/* illegal char */
@@ -2592,6 +2596,7 @@ static int annotate_canon_value(struct buf *value, int type)
     case ATTRIB_TYPE_INT:
 	/* make sure its a valid long */
 	errno = 0;
+	buf_cstring(value);
 	whatever = strtol(value->s, &p, 10);
 	if ((p == value->s)		/* no value */
 	    || (*p != '\0')		/* illegal char */
