@@ -607,84 +607,60 @@ static int mboxname_toexternal(struct namespace *namespace, const char *mboxname
 }
 
 /* Handle conversion from the internal namespace to the alternate namespace */
-static int mboxname_toexternal_alt(struct namespace *namespace, const char *name,
+static int mboxname_toexternal_alt(struct namespace *namespace, const char *mboxname,
 				  const char *userid, char *result)
 {
-    char *domain;
-    size_t userlen, resultlen;
+    char iresult[MAX_MAILBOX_NAME];
+    int r = 0;
 
-    /* Blank the result, just in case */
+    /* MUST blank the result */
     result[0] = '\0';
 
-    if(strlen(name) > MAX_MAILBOX_NAME) return IMAP_MAILBOX_BADNAME;
-    
-    if (!userid) return IMAP_MAILBOX_BADNAME;
+    // Make this abundantly simple
+    mboxname_toexternal(namespace, mboxname, userid, iresult);
 
-    userlen = strlen(userid);
+    r = strncasecmp(iresult, "inbox", 5);
 
-    if (config_virtdomains && (domain = strchr(userid, '@'))) {
-	size_t domainlen = strlen(domain);
-
-	userlen = domain - userid;
-
-	if (!strncmp(name, domain+1, domainlen-1) &&
-	    name[domainlen-1] == '!') {
-	    name += domainlen;
+    if (!r) {
+	if (iresult[5] == '\0') {
+	    // Just "INBOX"
+	    sprintf(result, "%s", iresult);
+	} else if (iresult[5] == namespace->hier_sep) {
+	    // INBOX/something
+	    sprintf(result, "%s", iresult+6);
 	}
+
+	return 0;
     }
 
-    /* Personal (INBOX) namespace */
-    if (!strncasecmp(name, "inbox", 5) &&
-	(name[5] == '\0' || name[5] == '.')) {
-	if (name[5] == '\0')
-	    strcpy(result, name);
-	else
-	    strcpy(result, name+6);
-    }
-    /* paranoia - this shouldn't be needed */
-    else if (!strncmp(name, "user.", 5) &&
-	     !strncmp(name+5, userid, userlen) &&
-	     (name[5+userlen] == '\0' ||
-	      name[5+userlen] == '.')) {
-	if (name[5+userlen] == '\0')
-	    strcpy(result, "INBOX");
-	else
-	    strcpy(result, name+5+userlen+1);
-    }
+    r = strncasecmp(iresult, "user", 4);
 
-    /* Other Users namespace */
-    else if (!strncmp(name, "user", 4) &&
-	     (name[4] == '\0' || name[4] == '.')) {
-	size_t prefixlen = strlen(namespace->prefix[NAMESPACE_USER]);
-
-	if ((prefixlen > MAX_MAILBOX_NAME) || 
-	    ((name[4] == '.') && 
-	     ((prefixlen+1+strlen(name+5)) > MAX_MAILBOX_NAME)))
-	    return IMAP_MAILBOX_BADNAME;
-
-	sprintf(result, "%.*s",
-		(int) (prefixlen-1), namespace->prefix[NAMESPACE_USER]);
-	resultlen = strlen(result);
-	if (name[4] == '.') {
-	    sprintf(result+resultlen, "%c%s", namespace->hier_sep, name+5);
-	}
-    }
-
-    /* Shared namespace */
-    else {
+    if (!r) {
+	if (iresult[4] == namespace->hier_sep) {
+	    // The namespace already has a hierarchy separator
+	    sprintf(result, "%s%s", namespace->prefix[NAMESPACE_USER], iresult+5);
 	/* special case:  LIST/LSUB "" % */
-	if (!strncmp(name, namespace->prefix[NAMESPACE_SHARED],
-		     strlen(namespace->prefix[NAMESPACE_SHARED])-1)) {
-	    strcpy(result, name);
-	}
-	else {
-	    strcpy(result, namespace->prefix[NAMESPACE_SHARED]);
-	    strcat(result, name);
+	} else {
+	    sprintf(result, "%.*s", (int)strlen(namespace->prefix[NAMESPACE_USER])-1, namespace->prefix[NAMESPACE_USER]);
 	}
+
+	return 0;
     }
 
-    /* Translate any separators in mailboxname */
-    mboxname_hiersep_toexternal(namespace, result, 0);
+    /* If not the personal namespace and not the other user namespace, then
+     * the shared folder namespace */
+
+    /* special case:  LIST/LSUB "" % */
+    if (!strncmp(mboxname, namespace->prefix[NAMESPACE_SHARED],
+	strlen(namespace->prefix[NAMESPACE_SHARED])-1)) {
+	strcpy(result, mboxname);
+    } else {
+	strcpy(result, namespace->prefix[NAMESPACE_SHARED]);
+	strcat(result, mboxname);
+    }
+
+    sprintf(result, "%s%s", namespace->prefix[NAMESPACE_SHARED], iresult);
+
     return 0;
 }
 
@@ -1458,11 +1434,15 @@ EXPORTED char *mboxname_metapath(const char *partition, const char *mboxname,
 	metaflag = IMAP_ENUM_METAPARTITION_FILES_ANNOTATIONS;
 	filename = FNAME_ANNOTATIONS;
 	break;
+
+#ifdef WITH_DAV
     case META_DAV:
 	snprintf(confkey, 256, "metadir-dav-%s", partition);
 	metaflag = IMAP_ENUM_METAPARTITION_FILES_DAV;
 	filename = FNAME_DAV;
 	break;
+#endif /* WITH_DAV */
+
     case 0:
 	break;
     default:
